==> mobiusft-1.11.tar.bz2: mobiusft-1.11/src/python/mobius/datetime/func_new_datetime_from_fat_time.cc <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief  C++ API module wrapper
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <Python.h>
#include <cstdint>
#include "api_datetime.h"

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief function new_datetime_from_fat_time
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
PyObject*
func_new_datetime_from_fat_time (PyObject *, PyObject *args)
{
  // parse arguments
  std::uint16_t arg_d = 0;
  std::uint16_t arg_t = 0;

  if (!PyArg_ParseTuple (args, "HH", &arg_d, &arg_t))
    return nullptr;

  // execute C++ code
  PyObject *ret = nullptr;

  try
    {
      ret = PyDateTime_from_datetime (
        mobius::datetime::new_datetime_from_fat_time (arg_d, arg_t)
      );
    }
  catch (const std::runtime_error& e)
    {
      Py_DECREF (ret);
      PyErr_SetString (PyExc_IOError, e.what ());
      ret = nullptr;
    }

  // return data
  return ret;
}

==> mobiusft-1.17.tar.bz2: mobiusft-1.17/src/python/mobius/datetime/func_new_datetime_from_fat_time.cc <==
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief  C++ API module wrapper
//! \author Eduardo Aguiar
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <pymobius.h>
#include <cstdint>

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief Function new_datetime_from_fat_time
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
PyObject*
func_new_datetime_from_fat_time (PyObject *, PyObject *args)
{
  // parse arguments
  std::uint16_t arg_d = 0;
  std::uint16_t arg_t = 0;

  if (!PyArg_ParseTuple (args, "HH", &arg_d, &arg_t))
    return nullptr;

  // execute C++ code
  PyObject *ret = nullptr;

  try
    {
      ret = mobius::py::pydatetime_from_datetime (
              mobius::datetime::new_datetime_from_fat_time (arg_d, arg_t)
            );
    }
  catch (const std::runtime_error& e)
    {
      Py_DECREF (ret);
      PyErr_SetString (PyExc_IOError, e.what ());
      ret = nullptr;
    }

  // return data
  return ret;
}
